@@ -25,6 +25,12 @@ fix () {
 		echo "Directory $d does not exist!"
 		sh mkinstalldirs $d
 	fi
+	old_version=` echo $p | sed -e "s,/$CONFIG_SUBDIR/,/,"`
+	if [ ! -f "$p" -a "$old_version" != "$p" -a -f "$old_version" ] ; then
+		echo "WARNING: Location of $p changed from $old_version"
+		echo "   Copying $old_version to $p"
+		cp "$old_version" "$p" || echo "cannot copy $old_version to $p"
+	fi
 	if [ -f $v.sample ] ; then
 		if [ $v.sample != $p.sample ] ; then ${INSTALL} -m 644 $v.sample $p.sample; fi
 	elif [ -f $v ] ; then
@@ -42,6 +48,9 @@ if [ "X$MAKEINSTALL" = "XYES" ] ; then
 	if [ -f lpd.perms ] ; then fix lpd.perms "${DESTDIR}${LPD_PERMS_PATH}" ; fi;
 	if [ -f lpd.conf ] ; then fix lpd.conf "${DESTDIR}${LPD_CONF_PATH}" ; fi;
 	if [ -f printcap ] ; then fix printcap "${DESTDIR}${PRINTCAP_PATH}" ; fi;
+	if [ -f init.generic ] ; then
+		${INSTALL} -m755 init.generic ` dirname ${DESTDIR}${LPD_CONF_PATH} `/lpd.init ;
+	fi;
 	if [ "$INIT" != "no" ] ; then
 		echo "Stopping LPD"
 		kill -INT `ps ${PSHOWALL} | awk '/lpd/{ print $1;}'` >/dev/null 2>&1
@@ -49,7 +58,7 @@ if [ "X$MAKEINSTALL" = "XYES" ] ; then
 		echo "Checking printcap"
 		${SBINDIR}/checkpc -f
 		echo "Starting LPD"
-		${LPD_PATH}
+		` dirname ${DESTDIR}${LPD_CONF_PATH} `/lpd.init start ;
 	fi
 fi
 exit 0
