@@ -18,11 +18,17 @@ fix () {
 		echo "$v is a filter '$p'" 
 		return 0
 	fi
-	echo "Checking for $v.sample in $d"
+	echo "Installing $v.sample in $d as $p"
 	if [ ! -d "$d" ] ; then
 		echo "Directory $d does not exist!"
 		mkdir -p $d;
 	fi
+	old_version=` echo $p | sed -e "s,/$CONFIG_SUBDIR/,/,"`
+	if [ ! -f "$p" -a "$old_version" != "$p" -a -f "$old_version" ] ; then
+		echo "WARNING: Location of $p changed from $old_version"
+		echo "   Copying $old_version to $p"
+		cp "$old_version" "$p" || echo "cannot copy $old_version to $p"
+	fi
 	if [ -f $v.sample ] ; then
 		if [ $v.sample != $p.sample ] ; then ${INSTALL} -m 644 $v.sample $p.sample; fi
 	elif [ -f $v ] ; then
@@ -38,51 +44,60 @@ fix () {
 }
 echo "Installing configuration files"
 init=${DESTDIR}/etc/rc.d/init.d/lpd
+if [ -n "${INIT}" ] ; then init=${DESTDIR}${INIT}; fi
+if [ -f /etc/redhat-release ] ; then
+	f=init.redhat;
+elif [ -d /lib/lsb ] ; then
+	f=init.linuxsb
+else
+	f=init.linux
+fi
 if [ "X$MAKEINSTALL" = "XYES" ] ; then
 	fix lpd.perms "${DESTDIR}${LPD_PERMS_PATH}"
 	fix lpd.conf "${DESTDIR}${LPD_CONF_PATH}"
 	fix printcap "${DESTDIR}${PRINTCAP_PATH}"
+	fix $f `dirname ${DESTDIR}${LPD_CONF_PATH}`/lpd
 	if [ "$INIT" != "no" ] ; then
 		if [ ! -d `dirname $init` ] ; then mkdir -p `dirname $init ` ; fi;
-        if [ -f /etc/redhat-release ] ; then
-			${INSTALL} -m 755 init.redhat $init;
-		elif [ -d /lib/lsb ] ; then
-			${INSTALL} -m 755 init.linuxsb $init;
-		else
-			${INSTALL} -m 755 init.linux $init;
-		fi
+		${INSTALL} -m 755 $f $init;
 	fi;
 else
 	fix "${LPD_PERMS_PATH}" "${DESTDIR}${LPD_PERMS_PATH}"
 	fix "${LPD_CONF_PATH}" "${DESTDIR}${LPD_CONF_PATH}"
 	fix "${PRINTCAP_PATH}" "${DESTDIR}${PRINTCAP_PATH}"
+	fix $f `dirname ${DESTDIR}${LPD_CONF_PATH}`/lpd
+	${INSTALL} -m 755 $f `dirname ${DESTDIR}${LPD_CONF_PATH}`/lpd
 fi
+
 if [ "X$MAKEPACKAGE" != "XYES" -a "$INIT" != no ] ; then
-    echo "Configuring startup scripts"
+    echo "Running startup scripts"
     if [ ! -f $init ] ; then
         echo "Missing $init";
+		exit 1
     fi
-    if [ -f /etc/redhat-release -a -f /sbin/chkconfig ] ; then
-		echo "RedHat Linux - running chkconfig"
+    if [ -f /sbin/chkconfig ] ; then
+		echo "Stopping CUPS server"
+		service cups stop || /bin/true
+		service cups-lpd stop || /bin/true
+		echo "Stopping LPD server"
+		service lpr stop || service lprng stop || service lpd stop || /bin/true
+		echo "running chkconfig"
 		(
 		/sbin/chkconfig lpr off
-		/sbin/chkconfig --del lpr
-		/sbin/chkconfig lpr off
-		/sbin/chkconfig --del lpr
+		/sbin/chkconfig lpd off
 		/sbin/chkconfig lprng off
-		/sbin/chkconfig --del lprng
+		/sbin/chkconfig cups off
+		/sbin/chkconfig cups-lpd off
+		/sbin/chkconfig `basename $init` off
 		)
-		echo "Stopping server"
-		kill -INT `ps ${PSHOWALL} | awk '/lpd/{ print $1;}'` >/dev/null 2>&1
-		sleep 2
 		echo "Checking Printcap"
 		${SBINDIR}/checkpc -f
-		echo "Installing Printer Startup Scripts"
-		/sbin/chkconfig --add lprng
-		/sbin/chkconfig --list lprng
-		/sbin/chkconfig lprng on
+		echo "Running LPRng Startup Scripts"
+		/sbin/chkconfig --add `basename $init`
+		/sbin/chkconfig --list `basename $init`
+		/sbin/chkconfig `basename $init` on
 		echo "Starting Printer"
-		sh $init start
+		service `basename $init` start
 		echo "Printer Started"
     else
 		echo "Stopping server"
@@ -91,25 +106,28 @@ if [ "X$MAKEPACKAGE" != "XYES" -a "$INIT" != no ] ; then
 		echo "Checking Printcap"
 		${SBINDIR}/checkpc -f
 		echo "Starting Printer"
-		${LPD_PATH}
+		sh `dirname ${DESTDIR}${LPD_CONF_PATH}`/lpd start
 		echo "Printer Started"
+		m=`dirname ${DESTDIR}${LPD_CONF_PATH}`/lpd
 		cat <<EOF
 # 
 # You will have to install the run time startup files by hand.
-# The $init file contains the standard startup/shutdown sequence.
-# You usually need to put in links to this file in /etc/rc.d/rcX.d
-# to have it executed by the appropriate run level startup/shutdown
-# script.
+# The $m file contains the standard startup/shutdown code.
+# You should put this file in the file in common set of rc startup
+# scripts and then make symbolic links to it from the run level
+# directories.
 #
 # You can use the following a template for your installation
-#
-	ln -s ../init.d/lprng /etc/rc0.d/K60lprng
-	ln -s ../init.d/lprng /etc/rc1.d/K60lprng
-	ln -s ../init.d/lprng /etc/rc2.d/S60lprng
-	ln -s ../init.d/lprng /etc/rc3.d/S60lprng
-	ln -s ../init.d/lprng /etc/rc4.d/S60lprng
-	ln -s ../init.d/lprng /etc/rc5.d/S60lprng
-	ln -s ../init.d/lprng /etc/rc6.d/K60lprng
+# 
+    initdir=/etc/rc.d
+    cp `dirname ${DESTDIR}${LPD_CONF_PATH}`/lpd  \${initdir}/lpd
+    ln -s ../init.d/lpd \${initdir}/rc0.d/K60lprng
+    ln -s ../init.d/lpd \${initdir}/rc1.d/K60lprng
+    ln -s ../init.d/lpd \${initdir}/rc2.d/S60lprng
+    ln -s ../init.d/lpd \${initdir}/rc3.d/S60lprng
+    ln -s ../init.d/lpd \${initdir}/rc4.d/S60lprng
+    ln -s ../init.d/lpd \${initdir}/rc5.d/S60lprng
+    ln -s ../init.d/lpd \${initdir}/rc6.d/K60lprng
 
 EOF
 	fi;
