@@ -8,7 +8,7 @@
  ***************************************************************************/
 
  static char *const _id =
-"$Id: lpd_control.c,v 1.57 2003/09/05 20:07:19 papowell Exp $";
+"$Id: lpd_control.c,v 1.74 2004/09/24 20:19:58 papowell Exp $";
 
 
 #include "lp.h"
@@ -35,8 +35,8 @@
    will happily put out the various control strings you need.
 	USED BY: start/stop, enable/disable, debug, forward, holdall
 
- 2. Individual jobs have a 'hold file' that is read/written by
-   the Get_ job_control and Set_ job_control routines.  These also
+ 2. Individual jobs have a 'job ticket file' that is read/written by
+   the Get_ job_ticket and Set_ job_ticket routines.  These also
    will read/write various control strings.
    USED by topq, hold, release
 
@@ -176,7 +176,7 @@ int Job_control( int *sock, char *input )
 			/* we have Nprinter user move jobid* target */
 			if( tokencount < 5 ){
 				SNPRINTF( error, sizeof(error))
-					_("Use: OP_MOVE printer (user|jobid)* target") );
+					_("Use: move printer (user|jobid)* target") );
 				goto error;
 			}
 			break;
@@ -232,7 +232,7 @@ void Do_printer_work( char *user, int action, int *sock,
  * Do_queue_control()
  * do the actual queue control operations
  * - start, stop, enable, disable are simple
- * - others are more complex, and are handled in Do_control_file
+ * - others are more complex, and are handled in Do_job_ticket_file
  * We have tokens:
  *   printer user printer p1 p2 p3 -> p1 p2 p3
  ***************************************************************************/
@@ -268,7 +268,7 @@ void Do_queue_control( char *user, int action, int *sock,
 
 	c = Debug;
 	i = DbgFlag;
-	end = Find_str_value(&Spool_control,DEBUG,Value_sep);
+	end = Find_str_value(&Spool_control,DEBUG);
 	if( !end ) end = New_debug_DYN;
 	Parse_debug( end, 0 );
 
@@ -321,6 +321,9 @@ void Do_queue_control( char *user, int action, int *sock,
 	case OP_PRINTCAP:
 		Do_control_printcap( sock );
 		goto done;
+	case OP_PPD:
+		Do_control_ppd( sock );
+		goto done;
 	case OP_STATUS:
 		if( Do_control_status( sock,
 			error, errorlen ) ){
@@ -361,7 +364,7 @@ void Do_queue_control( char *user, int action, int *sock,
 		Set_flag_value(&Spool_control,PRINTING_ABORTED, 0);
 		Set_flag_value(&Spool_control,PRINTING_DISABLED, 0);
 	case OP_HOLD:
-		if( Do_control_file( action, sock,
+		if( Do_job_ticket_file( action, sock,
 			tokens, error, errorlen, 0 ) ){
 			goto error;
 		}
@@ -384,7 +387,7 @@ void Do_queue_control( char *user, int action, int *sock,
 	case OP_MOVE:
 		--tokens->count;
 		start = tokens->list[tokens->count];
-		status = Do_control_file( action, sock,
+		status = Do_job_ticket_file( action, sock,
 			tokens, error, errorlen, start );
 		++tokens->count;
 		if( status ) goto error;
@@ -571,17 +574,17 @@ void Do_queue_control( char *user, int action, int *sock,
 
 
 /***************************************************************************
- * Do_control_file:
+ * Do_job_ticket_file:
  *  perform a suitable operation on a control file
  * 1. get the control files
  * 2. check to see if the control file has been selected
- * 3. update the hold file for the control file
+ * 3. update the job ticket file for the control file
  ***************************************************************************/
 
-int Do_control_file( int action, int *sock,
+int Do_job_ticket_file( int action, int *sock,
 	struct line_list *tokens, char *error, int errorlen, char *option )
 {
-	int i, permission, err;		/* ACME! Nothing but the best */
+	int i, permission, err, fd;		/* ACME! Nothing but the best */
 	int status, matchv;			/* status of last IO op */
 	char msg[SMALLBUFFER];		/* message field */
 	char *s, *identifier;
@@ -597,37 +600,39 @@ int Do_control_file( int action, int *sock,
 			0,0,0,0,0,0,0,0) ){
 		err = errno;
 		SNPRINTF(error, errorlen)
-			"Do_control_file: cannot read '%s' - '%s'",
+			"Do_job_ticket_file: cannot read '%s' - '%s'",
 			Spool_dir_DYN, Errormsg(err) );
 			return(1);
 	}
 
-	DEBUGF(DCTRL4)("Do_control_file: total files %d", Sort_order.count );
-	DEBUGFC(DCTRL2)Dump_line_list("Do_control_file - tokens", tokens);
+	DEBUGF(DCTRL4)("Do_job_ticket_file: total files %d", Sort_order.count );
+	DEBUGFC(DCTRL2)Dump_line_list("Do_job_ticket_file - tokens", tokens);
 
 	/* scan the files to see if there is one which matches */
 
 	status = 0;
+	fd = -1;
 	for( i = 0; status == 0 && i < Sort_order.count; ++i ){
 		/*
 		 * check to see if this entry matches any of the patterns
 		 */
+		if( fd > 0 ) close(fd); fd = -1;
 		Free_job(&job);
-		Get_hold_file( &job, Sort_order.list[i] );
-		DEBUGFC(DCTRL2)Dump_job("Do_control_file - getting info",&job);
-		identifier = Find_str_value(&job.info,IDENTIFIER,Value_sep);
-		if( identifier == 0 ) identifier = Find_str_value(&job.info,TRANSFERNAME,Value_sep);
+		Get_job_ticket_file( &fd, &job, Sort_order.list[i] );
+		DEBUGFC(DCTRL2)Dump_job("Do_job_ticket_file - getting info",&job);
+		identifier = Find_str_value(&job.info,IDENTIFIER);
+		if( identifier == 0 ) identifier = Find_str_value(&job.info,XXCFTRANSFERNAME);
 		if( identifier == 0 ) continue;
-		DEBUGF(DCTRL4)("Do_control_file: checking id '%s'", identifier );
+		DEBUGF(DCTRL4)("Do_job_ticket_file: checking id '%s'", identifier );
 
-		Perm_check.user = Find_str_value(&job.info,LOGNAME,Value_sep);
+		Perm_check.user = Find_str_value(&job.info,LOGNAME);
 		Perm_check.host = 0;
-		s = Find_str_value(&job.info,FROMHOST,Value_sep);
+		s = Find_str_value(&job.info,FROMHOST);
 		if( s && Find_fqdn( &PermHost_IP, s ) ){
 			Perm_check.host = &PermHost_IP;
 		}
 		permission = Perms_check( &Perm_line_list, &Perm_check, 0, 1 );
-		DEBUGF(DCTRL1)( "Do_control_file: id '%s', user '%s', host '%s', permission %s",
+		DEBUGF(DCTRL1)( "Do_job_ticket_file: id '%s', user '%s', host '%s', permission %s",
 			identifier, Perm_check.user, s, perm_str(permission) );
 		if( permission == P_REJECT ){
 			SNPRINTF( msg, sizeof(msg))
@@ -637,7 +642,7 @@ int Do_control_file( int action, int *sock,
 			continue;
 		}
 
-		destinations = Find_flag_value(&job.info,DESTINATIONS,Value_sep);
+		destinations = Find_flag_value(&job.info,DESTINATIONS);
 
 		update_dest = 0;
 
@@ -657,9 +662,9 @@ int Do_control_file( int action, int *sock,
 		}
 
 		DEBUGFC(DCTRL4){
-			LOGDEBUG("Do_control_file: selected id '%s'", identifier );
-			s = Find_str_value(&job.destination,IDENTIFIER,Value_sep);
-			LOGDEBUG("Do_control_file: update_dest %d, id '%s'", update_dest, s );
+			LOGDEBUG("Do_job_ticket_file: selected id '%s'", identifier );
+			s = Find_str_value(&job.destination,IDENTIFIER);
+			LOGDEBUG("Do_job_ticket_file: update_dest %d, id '%s'", update_dest, s );
 		}
 		
 		/* we report this job being selected */
@@ -685,6 +690,8 @@ int Do_control_file( int action, int *sock,
 			Set_flag_value(&job.info,PRIORITY_TIME,0 );
 			Set_flag_value(&job.info,DONE_TIME,0 );
 			Set_flag_value(&job.info,REMOVE_TIME,0 );
+			Set_flag_value(&job.info,ERROR_TIME,0 );
+			Set_str_value(&job.info,ERROR,0 );
 			setmessage( &job, TRACE, "LPC move" );
 			break;
 		case OP_RELEASE:
@@ -720,7 +727,7 @@ int Do_control_file( int action, int *sock,
 		Set_flag_value(&job.info,ERROR_TIME,0);
 		/* record the last update person */
 		Perm_check_to_list(&l, &Perm_check );
-		if( Set_hold_file(&job,&l,0) ){
+		if( Set_job_ticket_file(&job,&l,fd) ){
 			setmessage( &job, TRACE, "LPC failed" );
 			SNPRINTF( msg, sizeof(msg))
 				_("%s: cannot set hold file '%s'\n"),
@@ -732,6 +739,7 @@ int Do_control_file( int action, int *sock,
 			goto next_dest;
 		}
 	}
+	if( fd > 0 ) close(fd); fd = -1;
 	Free_job(&job);
 	Free_line_list(&Sort_order);
 	Free_line_list(&l);
@@ -968,7 +976,7 @@ int Do_control_class( int *sock,
 		goto error;
 	}
 
-	s = Find_str_value(&Spool_control,CLASS,Value_sep);
+	s = Find_str_value(&Spool_control,CLASS);
 
 	if( s ){
 		SNPRINTF( forward, sizeof(forward)) _("classes printed '%s'\n"),
@@ -1070,6 +1078,42 @@ int Do_control_printcap( int *sock )
 	return(0);
 }
 
+
+/***************************************************************************
+ * Do_control_ppd:
+ *  get the PPD file
+ * 1. get the ppd file name
+ * 2. if no ppdfile, write nothint
+ ***************************************************************************/
+
+int Do_control_ppd( int *sock )
+{
+	char *file = Ppd_file_DYN;
+	char buffer[LARGEBUFFER];
+	int fd, count;
+	struct stat statb;			/* status of file */
+
+	/* get the spool entries */
+
+	if( !ISNULL(file) ){
+		if( (fd = Checkread( file, &statb )) < 0 ){
+			SNPRINTF(buffer, sizeof(buffer)) "%s: cannot open '%s' - '%s'\n",
+				Printer_DYN, file, Errormsg(errno) );
+			Write_fd_str( *sock, buffer );
+		} else {
+			while( (count = ok_read(fd, buffer, sizeof(buffer)-1)) > 0 ){
+				if( Write_fd_len( *sock, buffer, count ) < 0 ) cleanup(0);
+			}
+			if( count < 0 ){
+				SNPRINTF(buffer, sizeof(buffer)) "%s: error reading '%s' - '%s'\n",
+					Printer_DYN, file, Errormsg(errno) );
+				if( Write_fd_str( *sock, buffer ) < 0 ) cleanup(0);
+			}
+		}
+	}
+	return(0);
+}
+
 int Do_control_defaultq( int *sock )
 {
 	char msg [LINEBUFFER];
