@@ -4,7 +4,7 @@
  * Copyright 1988-2003, Patrick Powell, San Diego, CA
  *     papowell@lprng.com
  * See LICENSE for conditions of use.
- * $Id: lpd_control.h,v 1.71 2004/05/03 20:24:05 papowell Exp $
+ * $Id: lpd_control.h,v 1.74 2004/09/24 20:20:00 papowell Exp $
  ***************************************************************************/
 
 
@@ -18,7 +18,7 @@ void Do_printer_work( char *user, int action, int *sock,
 	struct line_list *tokens, char *error, int errorlen );
 void Do_queue_control( char *user, int action, int *sock,
 	struct line_list *tokens, char *error, int errorlen );
-int Do_control_file( int action, int *sock,
+int Do_job_ticket_file( int action, int *sock,
 	struct line_list *tokens, char *error, int errorlen, char *option );
 int Do_control_lpq( char *user, int action,
 	struct line_list *tokens );
